Axial Dispersion closed-closed
==============================

.. automodule:: rtdpy.ad_cc
   :members:
   :inherited-members:
   :show-inheritance:
   :undoc-members:

.. automodule:: rtdpy.ad_cc_funcs
   :members:
   :inherited-members:
   :show-inheritance:
   :undoc-members:
